stalker.core.models.Entity
==========================

.. inheritance-diagram::
     stalker.core.models.Entity
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Entity
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Entity.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Entity.code
      ~Entity.created_by
      ~Entity.date_created
      ~Entity.date_updated
      ~Entity.description
      ~Entity.name
      ~Entity.nice_name
      ~Entity.notes
      ~Entity.tags
      ~Entity.type
      ~Entity.updated_by
   
   